@@ -31,16 +31,16 @@ class Fake : public KScreen::AbstractBackend
 
 public:
     explicit Fake();
-    virtual ~Fake();
+    ~Fake() override;
 
-    void init(const QVariantMap &arguments) Q_DECL_OVERRIDE;
+    void init(const QVariantMap &arguments) override;
 
-    QString name() const Q_DECL_OVERRIDE;
-    QString serviceName() const Q_DECL_OVERRIDE;
-    KScreen::ConfigPtr config() const Q_DECL_OVERRIDE;
-    void setConfig(const KScreen::ConfigPtr &config) Q_DECL_OVERRIDE;
-    QByteArray edid(int outputId) const Q_DECL_OVERRIDE;
-    bool isValid() const Q_DECL_OVERRIDE;
+    QString name() const override;
+    QString serviceName() const override;
+    KScreen::ConfigPtr config() const override;
+    void setConfig(const KScreen::ConfigPtr &config) override;
+    QByteArray edid(int outputId) const override;
+    bool isValid() const override;
 
     void setConnected(int outputId, bool connected);
     void setEnabled(int outputId, bool enabled);
