@@ -22,6 +22,8 @@
 #include "waylandoutput.h"
 #include "waylandscreen.h"
 
+#include "tabletmodemanager_interface.h"
+
 #include <configmonitor.h>
 #include <mode.h>
 
@@ -43,9 +45,12 @@ WaylandConfig::WaylandConfig(QObject *parent)
     , m_kscreenConfig(new Config)
     , m_kscreenPendingConfig(nullptr)
     , m_screen(new WaylandScreen(this))
+    , m_tabletModeAvailable(false)
+    , m_tabletModeEngaged(false)
 {
-    connect(this, &WaylandConfig::initialized, &m_syncLoop, &QEventLoop::quit);
+    initKWinTabletMode();
 
+    connect(this, &WaylandConfig::initialized, &m_syncLoop, &QEventLoop::quit);
     QTimer::singleShot(1000, this, [this] {
         if (m_syncLoop.isRunning()) {
             qCWarning(KSCREEN_WAYLAND) << "Connection to Wayland server at socket:"
@@ -67,6 +72,43 @@ WaylandConfig::~WaylandConfig()
     m_syncLoop.quit();
 }
 
+void WaylandConfig::initKWinTabletMode()
+{
+    auto *interface = new OrgKdeKWinTabletModeManagerInterface(QStringLiteral("org.kde.KWin"),
+                                                           QStringLiteral("/org/kde/KWin"),
+                                                           QDBusConnection::sessionBus(), this);
+    if (!interface->isValid()) {
+        m_tabletModeAvailable = false;
+        m_tabletModeEngaged = false;
+        return;
+    }
+
+    m_tabletModeAvailable = interface->tabletModeAvailable();
+    m_tabletModeEngaged = interface->tabletMode();
+
+    connect(interface, &OrgKdeKWinTabletModeManagerInterface::tabletModeChanged,
+            this, [this](bool tabletMode) {
+                if (m_tabletModeEngaged == tabletMode) {
+                    return;
+                }
+                m_tabletModeEngaged = tabletMode;
+                if (!m_blockSignals && m_initializingOutputs.empty()) {
+                    Q_EMIT configChanged();
+                }
+            }
+    );
+    connect(interface, &OrgKdeKWinTabletModeManagerInterface::tabletModeAvailableChanged,
+            this, [this](bool available) {
+                if (m_tabletModeAvailable == available) {
+                    return;
+                }
+                m_tabletModeAvailable = available;
+                if (!m_blockSignals && m_initializingOutputs.empty()) {
+                    Q_EMIT configChanged();
+                }
+    });
+}
+
 void WaylandConfig::initConnection()
 {
     m_thread = new QThread(this);
@@ -227,6 +269,9 @@ KScreen::ConfigPtr WaylandConfig::currentConfig()
     m_kscreenConfig->setScreen(m_screen->toKScreenScreen(m_kscreenConfig));
 
     auto features = Config::Feature::Writable | Config::Feature::PerOutputScaling;
+    // TODO: enable new features when all patches have landed
+//    const auto features = Config::Feature::Writable | Config::Feature::PerOutputScaling
+//                        | Config::Feature::AutoRotation | Config::Feature::TabletMode;
     m_kscreenConfig->setSupportedFeatures(features);
     m_kscreenConfig->setValid(m_connection->display());
 
@@ -258,6 +303,9 @@ KScreen::ConfigPtr WaylandConfig::currentConfig()
     }
     m_kscreenConfig->setOutputs(kscreenOutputs);
 
+    m_kscreenConfig->setTabletModeAvailable(m_tabletModeAvailable);
+    m_kscreenConfig->setTabletModeEngaged(m_tabletModeEngaged);
+
     return m_kscreenConfig;
 }
 
